pub struct LabVirtualMachineProperties {Show 20 fields
pub notes: Option<String>,
pub owner_object_id: Option<String>,
pub created_by_user_id: Option<String>,
pub created_by_user: Option<String>,
pub compute_id: Option<String>,
pub custom_image_id: Option<String>,
pub os_type: Option<String>,
pub size: Option<String>,
pub user_name: Option<String>,
pub password: Option<String>,
pub ssh_key: Option<String>,
pub is_authentication_with_ssh_key: Option<bool>,
pub fqdn: Option<String>,
pub lab_subnet_name: Option<String>,
pub lab_virtual_network_id: Option<String>,
pub disallow_public_ip_address: Option<bool>,
pub artifacts: Vec<ArtifactInstallProperties>,
pub artifact_deployment_status: Option<ArtifactDeploymentStatusProperties>,
pub gallery_image_reference: Option<GalleryImageReference>,
pub provisioning_state: Option<String>,
}Expand description
Properties of a virtual machine.
Fields
notes: Option<String>The notes of the virtual machine.
owner_object_id: Option<String>The object identifier of the owner of the virtual machine.
created_by_user_id: Option<String>The object identifier of the creator of the virtual machine.
created_by_user: Option<String>The email address of creator of the virtual machine.
compute_id: Option<String>The resource identifier (Microsoft.Compute) of the virtual machine.
custom_image_id: Option<String>The custom image identifier of the virtual machine.
os_type: Option<String>The OS type of the virtual machine.
size: Option<String>The size of the virtual machine.
user_name: Option<String>The user name of the virtual machine.
password: Option<String>The password of the virtual machine administrator.
ssh_key: Option<String>The SSH key of the virtual machine administrator.
is_authentication_with_ssh_key: Option<bool>A value indicating whether this virtual machine uses an SSH key for authentication.
fqdn: Option<String>The fully-qualified domain name of the virtual machine.
lab_subnet_name: Option<String>The lab subnet name of the virtual machine.
lab_virtual_network_id: Option<String>The lab virtual network identifier of the virtual machine.
disallow_public_ip_address: Option<bool>Indicates whether the virtual machine is to be created without a public IP address.
artifacts: Vec<ArtifactInstallProperties>The artifacts to be installed on the virtual machine.
artifact_deployment_status: Option<ArtifactDeploymentStatusProperties>Properties of an artifact deployment.
gallery_image_reference: Option<GalleryImageReference>The reference information for an Azure Marketplace image.
provisioning_state: Option<String>The provisioning status of the resource.
Implementations