pub struct Client(/* private fields */);Implementations
Sourceimpl Client
impl Client
Sourcepub fn list(
&self,
subscription_id: impl Into<String>,
resource_group_name: impl Into<String>,
lab_name: impl Into<String>,
artifact_source_name: impl Into<String>,
) -> RequestBuilder
pub fn list( &self, subscription_id: impl Into<String>, resource_group_name: impl Into<String>, lab_name: impl Into<String>, artifact_source_name: impl Into<String>, ) -> RequestBuilder
List artifacts in a given artifact source.
Arguments:
subscription_id: The subscription ID.resource_group_name: The name of the resource group.lab_name: The name of the lab.artifact_source_name: The name of the artifact source.
Sourcepub fn get(
&self,
subscription_id: impl Into<String>,
resource_group_name: impl Into<String>,
lab_name: impl Into<String>,
artifact_source_name: impl Into<String>,
name: impl Into<String>,
) -> RequestBuilder
pub fn get( &self, subscription_id: impl Into<String>, resource_group_name: impl Into<String>, lab_name: impl Into<String>, artifact_source_name: impl Into<String>, name: impl Into<String>, ) -> RequestBuilder
Get artifact.
Arguments:
subscription_id: The subscription ID.resource_group_name: The name of the resource group.lab_name: The name of the lab.artifact_source_name: The name of the artifact source.name: The name of the artifact.
Sourcepub fn generate_arm_template(
&self,
subscription_id: impl Into<String>,
resource_group_name: impl Into<String>,
lab_name: impl Into<String>,
artifact_source_name: impl Into<String>,
name: impl Into<String>,
generate_arm_template_request: impl Into<GenerateArmTemplateRequest>,
) -> RequestBuilder
pub fn generate_arm_template( &self, subscription_id: impl Into<String>, resource_group_name: impl Into<String>, lab_name: impl Into<String>, artifact_source_name: impl Into<String>, name: impl Into<String>, generate_arm_template_request: impl Into<GenerateArmTemplateRequest>, ) -> RequestBuilder
Generates an ARM template for the given artifact, uploads the required files to a storage account, and validates the generated artifact.
Arguments:
subscription_id: The subscription ID.resource_group_name: The name of the resource group.lab_name: The name of the lab.artifact_source_name: The name of the artifact source.name: The name of the artifact.generate_arm_template_request: Parameters for generating an ARM template for deploying artifacts.