pub struct WeekDetails {
pub weekdays: Vec<String>,
pub time: Option<String>,
}Expand description
Properties of a weekly schedule.
Fields
weekdays: Vec<String>The days of the week for which the schedule is set (e.g. Sunday, Monday, Tuesday, etc.).
time: Option<String>The time of the day the schedule will occur.
Implementations
Sourceimpl WeekDetails
impl WeekDetails