pub struct NotificationChannelProperties {
pub web_hook_url: Option<String>,
pub email_recipient: Option<String>,
pub notification_locale: Option<String>,
pub description: Option<String>,
pub events: Vec<Event>,
pub created_date: Option<OffsetDateTime>,
pub provisioning_state: Option<String>,
pub unique_identifier: Option<String>,
}Expand description
Properties of a schedule.
Fields
web_hook_url: Option<String>The webhook URL to send notifications to.
email_recipient: Option<String>The email recipient to send notifications to (can be a list of semi-colon separated email addresses).
notification_locale: Option<String>The locale to use when sending a notification (fallback for unsupported languages is EN).
description: Option<String>Description of notification.
events: Vec<Event>The list of event for which this notification is enabled.
created_date: Option<OffsetDateTime>The creation date of the notification channel.
provisioning_state: Option<String>The provisioning status of the resource.
unique_identifier: Option<String>The unique immutable identifier of a resource (Guid).
Implementations