pub struct NotificationSettings {
pub status: Option<Status>,
pub time_in_minutes: Option<i32>,
pub webhook_url: Option<String>,
pub email_recipient: Option<String>,
pub notification_locale: Option<String>,
}Expand description
Notification settings for a schedule.
Fields
status: Option<Status>If notifications are enabled for this schedule (i.e. Enabled, Disabled).
time_in_minutes: Option<i32>Time in minutes before event at which notification will be sent.
webhook_url: Option<String>The webhook URL to which the notification will be sent.
email_recipient: Option<String>The email recipient to send notifications to (can be a list of semi-colon separated email addresses).
notification_locale: Option<String>The locale to use when sending a notification (fallback for unsupported languages is EN).
Implementations